Version 6.0～7.0
=================

Version6.0～7.0までのリリースノートです。

## :package: 6.1.0

:fontawesome-solid-calendar: `2026-03-11`

??? info "miroir addon で DynamoDB と S3 の endpoint を個別指定できるようになりました"

    * [Moto] などを使って DynamoDB / S3 の接続先を個別に切り替えられます
    * 詳細は [miroir] > [Endpoints] をご覧ください

!!! danger "Python3.9のサポートを終了しました"

!!! note "セキュリティアップデート"

## :package: 6.0.1

:fontawesome-solid-calendar: `2025-09-27`

!!! note "セキュリティアップデート"

## :package: 6.0.0

:fontawesome-solid-calendar: `2025-01-04`

!!! info "Python3.13をサポートするようになりました"

!!! danger "Python3.8のサポートを終了しました"

!!! note "セキュリティアップデート"

!!! note "Poetryの代わりにuvを使用するようにしました"

[Moto]: https://docs.getmoto.org/
[miroir]: ../addons/final.md#miroir
[Endpoints]: ../addons/final.md#endpoints
